{{- define "alerta" -}}
{{/* https://docs.python.org/3/library/logging.html#levels */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "DEBUG" "debug" "DEBUG" "info" "INFO" "warn" "WARNING" "error" "ERROR" "crit" "CRITICAL") "component" "alerta" | include "stacklight.logLevel" -}}
alertaConfig:
  AUTH_REQUIRED: "False"
  DATABASE_URL: "postgresql://alerta:alertadb@{{ include "stacklight.currentPatroni" . }}:5432/alerta"
  ALERT_TIMEOUT: "21600"
  {{- if $logLevel }}
  LOG_LEVEL: {{ $logLevel | quote }}
  {{- end }}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "alerta") | nindent 2 }}
buffer: {{ .Values.alerta.buffer | toYaml | nindent 2 }}
replicaCount: 2
affinity:
  podAntiAffinity:
    preferredDuringSchedulingIgnoredDuringExecution:
    - weight: 100
      podAffinityTerm:
        topologyKey: "kubernetes.io/hostname"
        labelSelector:
          matchExpressions:
          - key: app
            operator: In
            values:
            - alerta
          - key: release
            operator: In
            values:
            - alerta
{{- if .Values.exposeLoadBalancers }}
service:
  type: LoadBalancer
{{- end }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "alerta") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "alerta") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "alerta") }}
{{- end }}
