{{- define "cortex" -}}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "cortex") | nindent 2 }}
tags:
  blocks-storage-memcached: true
alertmanager:
  enabled: true
  statefulSet:
    enabled: true
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexAlertmanager") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    enabled: true
    size: 2Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexAlertManager }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexAlertManager }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexAlertManager }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
{{- if .Values.highAvailabilityEnabled }}
  replicas: 2
{{- else }}
  replicas: 1
{{- end }}
  extraVolumes:
  - name: tmp
    emptyDir: {}
  extraVolumeMounts:
  - mountPath: /tmp
    name: tmp

ruler:
  enabled: true
{{- if .Values.highAvailabilityEnabled }}
  replicas: 2
{{- else }}
  replicas: 1
{{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexRuler") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

distributor:
{{- if .Values.highAvailabilityEnabled }}
  replicas: 3
{{- else }}
  replicas: 1
{{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexDistributor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

ingester:
  extraAgrs:
    blocks-storage.tsdb.retention-period: {{ .Values.cortexDev.retentionTime.ingester }}
  statefulSet:
    enabled: true
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexIngester") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    enabled: true
    size: 16Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexIngester }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexIngester }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexIngester }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
{{- if .Values.highAvailabilityEnabled }}
  replicas: 3
{{- else }}
  replicas: 1
{{- end }}

compactor:
  enabled: true
  replicas: 1
  extraAgrs:
    compactor.blocks-retention-period: {{ .Values.cortexDev.retentionTime.lts }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexCompactor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    enabled: true
    size: 16Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexCompactor }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexCompactor }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexCompactor }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexCompactor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}

querier:
  extraArgs:
    querier.query-ingesters-within: {{ .Values.cortexDev.retentionTime.ingester }}
{{- if .Values.highAvailabilityEnabled }}
  replicas: 2
{{- else }}
  replicas: 1
{{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexQuerier") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

query_frontend:
{{- if .Values.highAvailabilityEnabled }}
  replicas: 2
{{- else }}
  replicas: 1
{{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexQueryFrontend") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

store_gateway:
{{- if .Values.highAvailabilityEnabled }}
  replicas: 2
{{- else }}
  replicas: 1
{{- end }}
  persistentVolume:
    enabled: true
    size: 2Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexStoreGateway }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexStoreGateway }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexStoreGateway }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexStoreGateway") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}

nginx:
  enabled: true
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "nginx") | nindent 4 }}
{{- if .Values.highAvailabilityEnabled }}
  replicas: 3
{{- else }}
  replicas: 1
{{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexNginx") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

config:
  server:
    log_level: debug
  storage:
    engine: blocks
  blocks_storage:
    bucket_store:
      bucket_index:
        enabled: true
      sync_dir: /data/tsdb-sync
      chunks_cache:
        backend: memcached
        memcached:
          addresses: cortex-memcached-blocks:11211
      index_cache:
        backend: memcached
        memcached:
          addresses: cortex-memcached-blocks-index:11211
      metadata_cache:
        backend: memcached
        memcached:
          addresses: cortex-memcached-blocks-metadata:11211
    tsdb:
      dir: /data/tsdb
    backend: s3
    s3:
      bucket_name: {{ .Values.cortexDev.buckets.blocks.name }}
      endpoint: "minio:9000"
      access_key_id: {{ .Values.minio.cortexUser.name | quote }}
      secret_access_key: {{ .Values.minio.cortexUser.password | quote }}
      insecure: true
      signature_version: v2
  store_gateway:
    sharding_enabled: true
    sharding_ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/collectors/"
  distributor:
{{- if .Values.highAvailabilityEnabled }}
    ha_tracker:
      enable_ha_tracker: true
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/ha-tracker/"
{{- end }}
    ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/collectors/"
  ingester:
    lifecycler:
      ring:
{{- if .Values.highAvailabilityEnabled }}
        replication_factor: 3
{{- else }}
        replication_factor: 1
{{- end }}
        kvstore:
          store: etcd
          etcd:
            tls_enabled: false
            tls_insecure_skip_verify: false
            endpoints: ["etcd:2379"]
          prefix: "cortex/collectors/"
  compactor:
    sharding_ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/collectors/"
  ruler:
    enable_api: true
    enable_sharding: true
    enable_alertmanager_v2: true
    ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/rulers/"
  ruler_storage:
    backend: s3
    s3:
      endpoint: "minio:9000"
      access_key_id: {{ .Values.minio.cortexUser.name | quote }}
      secret_access_key: {{ .Values.minio.cortexUser.password | quote }}
      insecure: true
      signature_version: v2
      bucket_name: {{ .Values.cortexDev.buckets.notifications.name }}
  alertmanager:
    enable_api: true
    sharding_enabled: true
    sharding_ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/alertmanagers/"
  alertmanager_storage:
    backend: s3
    s3:
      endpoint: "minio:9000"
      access_key_id: {{ .Values.minio.cortexUser.name | quote }}
      secret_access_key: {{ .Values.minio.cortexUser.password | quote }}
      insecure: true
      signature_version: v2
      bucket_name: {{ .Values.cortexDev.buckets.notifications.name }}
{{- end -}}
