{{- define "etcd" -}}
image:
  {{- $image := include "stacklight.getImage" (dict "root" . "image" "etcd") | fromYaml }}
  {{- $repo := splitn "/" 2 (index $image "repository") }}
  {{- $_ := set $image "registry" $repo._0 }}
  {{- $_ := set $image "repository" $repo._1 }}
  {{- $image | toYaml | nindent 2 }}
{{- if .Values.highAvailabilityEnabled }}
podAntiAffinityPreset: hard
replicaCount: 3
{{- else }}
podAntiAffinityPreset: soft
replicaCount: 1
{{- end }}
auth:
  rbac:
    enabled: false
    rootPassword: etcd

autoCompactionMode: periodic
autoCompactionRetention: 1
extraEnvVars:
- name: ETCD_QUOTA_BACKEND_BYTES
  value: "8589934592"
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "etcd") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "etcd") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "etcd") }}
persistence:
  enabled: true
  size: {{ .Values.etcd.persistentVolumeClaimSize }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.etcd }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.etcd }}
    {{- $storageClass = .Values.storage.componentStorageClasses.etcd }}
  {{- end }}
global:
  storageClass: "{{ $storageClass }}"
{{- end }}
{{- end -}}
