{{- define "fluentd.common" -}}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "fluentd") | nindent 2 }}
{{- end -}}

{{- define "fluentdElasticsearch" -}}
{{/* https://docs.fluentd.org/deployment/logging#log-level */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "trace" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "crit" "fatal") "component" "fluentdElasticsearch" | include "stacklight.logLevel" -}}
{{- if $logLevel }}
systemConf:
  log_level: {{ $logLevel }}
{{- end }}
{{ include "fluentd.common" . }}
livenessProbe:
  enabled: true
{{- $resources := include "stacklight.resources" (dict "inTplValues" .Values "service" "fluentdElasticsearch") | fromYaml }}
{{- $limitMem := include "memStringToMB" $resources.resources.limits.memory | int64 }}
{{- $bufferMem := div $limitMem 4 }}
elasticsearch:
  auth:
    enabled: false
    user: "yourUser"
    password: "yourPass"
  buffer_chunk_limit: 16m
  buffer_total_limit: {{ $bufferMem }}m
  host: 'elasticsearch-master'
  logstash_prefix: 'logstash'
  logstash_date_format: '%Y.%m.%d.%H'
  port: 9200
  scheme: 'http'
  ssl_version: TLSv1_2
updateStrategy:
  rollingUpdate:
    maxUnavailable: 100%
  type: RollingUpdate
tolerations:
- key: "node-role.kubernetes.io/master"
  operator: "Exists"
  effect: "NoSchedule"
{{- if .Values.mke.enabled }}
- key: "com.docker.ucp.manager"
  operator: "Exists"
  effect: "NoSchedule"
{{- end }}
{{- $tolerations := (concat .Values.tolerations.default .Values.tolerations.component.fluentdElasticsearch) | uniq }}
{{- if $tolerations }}
  {{ toYaml $tolerations | nindent 0 }}
{{- end }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "fluentdElasticsearch") }}
{{- if .Values.nodeSelector.component.fluentdElasticsearch }}
nodeSelector:
  {{ toYaml .Values.nodeSelector.component.fluentdElasticsearch | nindent 2 }}
{{- end }}
initContainers:
  fluentd-elasticsearch-check:
    image: {{ include "stacklight.getImage" (dict "root" . "image" "curl" "flat" true) | quote }}
logLevel: {{ .Values.logging.level }}
syslog:
  {{- $syslog := .Values.logging.syslog }}
  {{- if .Values.clusterId }}
    {{- $_ := set $syslog "hostname" (.Values.clusterId | replace "/" "_") }}
  {{- end }}
  {{- $syslog | toYaml | nindent 2 }}
{{- end -}}

{{- define "fluentdNotifications" -}}
{{/* https://docs.fluentd.org/deployment/logging#log-level */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "trace" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "crit" "fatal") "component" "fluentd" | include "stacklight.logLevel" -}}
{{- if $logLevel }}
systemConf:
  log_level: {{ $logLevel }}
{{- end }}
{{ include "fluentd.common" . }}
{{- if .Values.highAvailabilityEnabled }}
replicaCount: 2
affinity:
  podAntiAffinity:
    requiredDuringSchedulingIgnoredDuringExecution:
    - labelSelector:
        matchExpressions:
        - key: app
          operator: In
          values:
          - "fluentd"
      topologyKey: "kubernetes.io/hostname"
{{- end }}
livenessProbe:
  enabled: true
  failureThreshold: 10
  periodSeconds: 60
output:
  host: elasticsearch-master
  port: 9200
env:
  RABBITMQ_HOST: "{{ .Values.openstack.rabbitmq.credentialsConfig.host }}"
  RABBITMQ_USER: "{{ .Values.openstack.rabbitmq.credentialsConfig.username }}"
  RABBITMQ_PASS: "{{ .Values.openstack.rabbitmq.credentialsConfig.password }}"
  RABBITMQ_VHOST: "{{ .Values.openstack.rabbitmq.credentialsConfig.vhost }}"

queuePrefix: "{{ .Values.openstack.rabbitmq.credentialsConfig.queue }}"
queueSeverities:
  - audit
  - critical
  - debug
  - error
  - info
  - sample
  - warn

elasticsearchCheck:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "curl") | nindent 4 }}
rabbitmqCredentialsDiscovery:
  enabled: {{ .Values.openstack.rabbitmq.credentialsDiscovery.enabled }}
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "curlJq") | nindent 4 }}
  namespace: {{ .Values.openstack.rabbitmq.credentialsDiscovery.namespace }}
  secretName: {{ .Values.openstack.rabbitmq.credentialsDiscovery.secretName }}
{{- if .Values.openstack.rabbitmq.credentialsDiscovery.secretChecksum }}
  secretChecksum: {{ .Values.openstack.rabbitmq.credentialsDiscovery.secretChecksum }}
{{- end }}
persistence:
  enabled: false

{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "fluentdNotifications") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "fluentd") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "fluentd") }}
{{- end -}}
