{{- define "iamProxy.common" -}}
global:
  dockerBaseUrl: {{ .Values.global.dockerBaseUrl }}
{{- if .Values.global.serviceAnnotations }}
  serviceAnnotations:
    {{- toYaml .Values.global.serviceAnnotations | nindent 4 }}
{{- end }}
service:
  type: LoadBalancer
  {{- if .Values.iam.tls.enabled }}
  port: 443
  {{- else }}
  port: 80
  {{- end }}
oauth2:
  discoveryUrl: "{{ .Values.iam.url }}/auth/realms/iam"
  client:
    id: "{{ .Values.iam.client }}"
  providerCASecretName: "{{ .Values.iam.oidcCASecret }}"
  tls:
    enabled: {{ .Values.iam.tls.enabled }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxy") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "iamProxy") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "iamProxy") }}
{{- end -}}

{{- define "iamProxy.alertaOverride" -}}
oauth2:
  tls:
    certsSecretName: "iam-proxy-alerta-tls-certs"
  upstreams: ["http://alerta"]
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:alerta@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.alerta" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyAlertaOverride := include "iamProxy.alertaOverride" . | fromYaml }}
{{- merge $iamProxyAlertaOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.alertmanagerOverride" -}}
oauth2:
  tls:
    certsSecretName: "iam-proxy-alertmanager-tls-certs"
  upstreams: ["http://prometheus-alertmanager"]
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:alertmngmt@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.alertmanager" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyAlertmanagerOverride := include "iamProxy.alertmanagerOverride" . | fromYaml }}
{{- merge $iamProxyAlertmanagerOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.grafanaOverride" -}}
oauth2:
  tls:
    certsSecretName: "iam-proxy-grafana-tls-certs"
  upstreams: ["http://grafana"]
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:grafana@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.grafana" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyGrafanaOverride := include "iamProxy.grafanaOverride" . | fromYaml }}
{{- merge $iamProxyGrafanaOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.kibanaOverride" -}}
oauth2:
  tls:
    certsSecretName: "iam-proxy-kibana-tls-certs"
  upstreams: ["http://kibana"]
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:kibana@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.kibana" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyKibanaOverride := include "iamProxy.kibanaOverride" . | fromYaml }}
{{- merge $iamProxyKibanaOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.prometheusOverride" -}}
oauth2:
  tls:
    certsSecretName: "iam-proxy-prometheus-tls-certs"
  upstreams: ["http://prometheus-server"]
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:pm@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.prometheus" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyPrometheusOverride := include "iamProxy.prometheusOverride" . | fromYaml }}
{{- merge $iamProxyPrometheusOverride $iamProxyCommon | toYaml }}
{{- end -}}
