{{- define "memcached.common" -}}
image:
  {{- $image := include "stacklight.getImage" (dict "root" . "image" "memcached") | fromYaml }}
  {{- $repo := splitn "/" 2 (index $image "repository") }}
  {{- $_ := set $image "registry" $repo._0 }}
  {{- $_ := set $image "repository" $repo._1 }}
  {{- $image | toYaml | nindent 2 }}
{{- if .Values.highAvailabilityEnabled }}
podAntiAffinityPreset: hard
architecture: high-availability
replicaCount: 3
{{- else }}
podAntiAffinityPreset: soft
architecture: standalone
replicaCount: 1
{{- end }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "memcached") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "memcached") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "memcached") }}
persistence:
  enabled: {{ .Values.cortexDev.cache.persistent }}
  size: {{ .Values.cortexDev.cache.persistentVolumeClaimSize }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.memcached }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.memcached }}
    {{- $storageClass = .Values.storage.componentStorageClasses.memcached }}
  {{- end }}
global:
  storageClass: "{{ $storageClass }}"
{{- end }}
{{- end -}}

{{- define "memcached.cortex" -}}
{{ include "memcached.common" . }}
{{- end -}}

{{- define "memcached.cortex-index" -}}
{{ include "memcached.common" . }}
{{- end -}}

{{- define "memcached.cortex-metadata" -}}
{{ include "memcached.common" . }}
{{- end -}}
