{{- define "minio" -}}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "minioServer") | nindent 2 }}
mcImage:
  {{- include "stacklight.getImage" (dict "root" . "image" "minioClient") | nindent 2 }}
{{- if .Values.highAvailabilityEnabled }}
mode: distributed
drivesPerNode: 2
replicas: 3
{{- else }}
mode: standalone
{{- end }}
extraArgs: []
rootUser: {{ .Values.minio.rootUser.name }}
rootPassword: {{ .Values.minio.rootUser.password }}
persistence:
  enabled: true
  size: {{ .Values.minio.persistentVolumeClaimSize }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.minio }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.minio }}
    {{- $storageClass = .Values.storage.componentStorageClasses.minio }}
  {{- end }}
  storageClass: "{{ $storageClass }}"
{{- end }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "minio") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "minio") }}
affinity:
  podAntiAffinity:
{{- if .Values.highAvailabilityEnabled }}
    requiredDuringSchedulingIgnoredDuringExecution:
    - topologyKey: "kubernetes.io/hostname"
      labelSelector:
        matchExpressions:
        - key: app
          operator: In
          values:
          - minio
        - key: release
          operator: In
          values:
          - minio
{{- else }}
    preferredDuringSchedulingIgnoredDuringExecution:
    - weight: 100
      podAffinityTerm:
        topologyKey: "kubernetes.io/hostname"
        labelSelector:
          matchExpressions:
          - key: app
            operator: In
            values:
            - minio
          - key: release
            operator: In
            values:
            - minio
{{- end }}
securityContext:
  enabled: false
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "minio") }}
users:
- accessKey: {{ .Values.minio.cortexUser.name }}
  secretKey: {{ .Values.minio.cortexUser.password }}
  policy: readwrite
makeUserJob:
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "minioJobs") | nindent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "minio") | nindent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "minio") | nindent 2 }}
buckets:
- name: {{ .Values.cortexDev.buckets.blocks.name }}
  policy: none
  purge: false
- name: {{ .Values.cortexDev.buckets.notifications.name }}
  policy: none
  purge: false
makeBucketJob:
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "minioJobs") | nindent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "minio") | nindent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "minio") | nindent 2 }}
environment: {}
podDisruptionBudget:
  enabled: {{ .Values.highAvailabilityEnabled }}
{{- end -}}
