{{- define "prometheus.esExporter" -}}
{{/* https://docs.python.org/3/library/logging.html#levels */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "DEBUG" "debug" "DEBUG" "info" "INFO" "warn" "WARNING" "error" "ERROR" "crit" "CRITICAL") "component" "prometheusEsExporter" | include "stacklight.logLevel" }}
es:
  uri: elasticsearch-master:9200
extraArgs:
- "--nodes-stats-disable"
- "--cluster-health-disable"
- "--indices-stats-disable"
{{- if $logLevel }}
- "--log-level={{ $logLevel }}"
{{- end }}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "prometheusEsExporter") | nindent 2 }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "prometheusEsExporter") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "prometheusEsExporter") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "prometheusEsExporter") }}
{{- if or .Values.logging.metricQueries .Values.openstack.enabled }}
extraQueries:
  {{- $extraQueries := dict }}
  {{- if .Values.openstack.enabled }}
    {{- $extraQueries = .Files.Get "files/prometheus-es-exporter-queries.yaml" | fromYaml }}
  {{- end }}
  {{- range $metric, $config := .Values.logging.metricQueries }}
    {{- $newConfig := deepCopy $config }}
    {{- if hasKey $extraQueries $metric }}
      {{- if $newConfig }}
        {{- $newConfig = mergeOverwrite (index $extraQueries $metric) $config }}
      {{- end }}
    {{- end }}
    {{- if not $newConfig }}
      {{- $_ := unset $extraQueries $metric }}
    {{- else }}
      {{- $_ := set $extraQueries $metric $newConfig }}
    {{- end }}
  {{- end }}
  {{- $extraQueries | toYaml | nindent 2 }}
{{- end }}
{{- end -}}
