{{- define "prometheus.extraScrapeConfigs" -}}
{{- $MKEAPIPort := 0 }}
{{- $MKEKubernetesAPIPort := 0 }}
{{- if .Values.mke.enabled }}
  {{- $MKEAPIPort = .Values.mke.APIPort }}
  {{- $MKEKubernetesAPIPort = .Values.mke.kubernetesAPIPort }}
  {{- if hasKey .Values "ucp" }}
    {{- if hasKey .Values.ucp "APIPort" }}
      {{- $MKEAPIPort = .Values.ucp.APIPort }}
    {{- end }}
    {{- if hasKey .Values.ucp "kubernetesAPIPort" }}
      {{- $MKEKubernetesAPIPort = .Values.ucp.kubernetesAPIPort }}
    {{- end }}
  {{- end }}
{{- end }}
extraScrapeConfigs:
  {{- if .Values.mke.enabled }}
  telegraf-docker-swarm:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 15s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name]
      regex: telegraf-docker-swarm
      action: keep

  mke-manager-api:
    metrics_path: /probe
    honor_timestamps: true
    scrape_interval: 15s
    scrape_timeout: 10s
    params:
      module: [http_2xx]
    kubernetes_sd_configs:
      - role: node
    relabel_configs:
      - source_labels: [__meta_kubernetes_node_labelpresent_node_role_kubernetes_io_master]
        action: keep
        regex: true
      - source_labels: [__meta_kubernetes_node_address_InternalIP]
        regex: (.+)
        replacement: 'https://${1}:{{ $MKEAPIPort }}/_ping'
        target_label: __param_target
      - source_labels: [__param_target]
        target_label: instance
      - source_labels: [__param_module]
        target_label: blackbox_probe_module
      - target_label: __address__
        replacement: prometheus-blackbox-exporter:9115
      - source_labels: [__meta_kubernetes_node_name]
        target_label: node

  mke-metrics-engine:
    scrape_interval: 10s
    scrape_timeout: 10s
    scheme: https
    tls_config:
      ca_file: /tmp/mkecerts/ca.pem
      cert_file: /tmp/mkecerts/cert.pem
      key_file: /tmp/mkecerts/key.pem
      insecure_skip_verify: true
    bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
    kubernetes_sd_configs:
      - role: node
    relabel_configs:
      - source_labels: [__meta_kubernetes_node_name]
        target_label: node
      - source_labels: [__meta_kubernetes_node_address_InternalIP]
        regex: (.+)
        replacement: '${1}:12376'
        target_label: __address__

  mke-metrics-controller:
    scrape_interval: 10s
    scrape_timeout: 10s
    scheme: https
    tls_config:
      ca_file: /tmp/mkecerts/ca.pem
      cert_file: /tmp/mkecerts/cert.pem
      key_file: /tmp/mkecerts/key.pem
      insecure_skip_verify: true
    bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
    kubernetes_sd_configs:
      - role: node
    relabel_configs:
      - action: labelmap
        regex: __meta_kubernetes_node_label_(.+)
      - source_labels: [__meta_kubernetes_node_labelpresent_node_role_kubernetes_io_master]
        action: keep
        regex: true
      - source_labels: [__meta_kubernetes_node_address_InternalIP]
        regex: (.+)
        replacement: '${1}:{{ $MKEAPIPort }}'
        target_label: __address__

    {{- if .Values.msrMonitoring.enabled }}
  msr-api:
    metrics_path: /probe
    honor_timestamps: true
    scrape_interval: 15s
    scrape_timeout: 10s
    params:
      module: [http_2xx]
    static_configs:
      - targets: {{ .Values.msrMonitoring.msrIPs | toJson }}
    relabel_configs:
      - source_labels: [__address__]
        regex: (.+)
        replacement: 'https://${1}:{{ $MKEAPIPort }}/_ping'
        target_label: __param_target
      - source_labels: [__param_target]
        target_label: instance
      - source_labels: [__param_module]
        target_label: blackbox_probe_module
      - target_label: __address__
        replacement: prometheus-blackbox-exporter:9115
    {{- end }}

  mke-istio-mesh:
    kubernetes_sd_configs:
      - role: endpoints
        namespaces:
          names:
            - istio-system
    relabel_configs:
      - source_labels: [__meta_kubernetes_service_name, __meta_kubernetes_endpoint_port_name]
        action: keep
        regex: istio-telemetry;prometheus

  mke-istio-telemetry:
    kubernetes_sd_configs:
      - role: endpoints
        namespaces:
          names:
            - istio-system
    relabel_configs:
      - source_labels: [__meta_kubernetes_service_name, __meta_kubernetes_endpoint_port_name]
        action: keep
        regex: istio-telemetry;http-monitoring

  mke-istio-pilot:
    kubernetes_sd_configs:
      - role: endpoints
        namespaces:
          names:
            - istio-system
    relabel_configs:
      - source_labels: [__meta_kubernetes_service_name, __meta_kubernetes_endpoint_port_name]
        action: keep
        regex: istio-pilot;http-monitoring
      - source_labels: [__meta_kubernetes_service_label_app]
        target_label: app
  {{- end }}

  {{- if and .Values.sslCertificateMonitoring.enabled .Values.sslCertificateMonitoring.domains }}
  blackbox:
    metrics_path: /probe
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    params:
      module: [http_2xx_verify]
    static_configs:
      - targets: {{ .Values.sslCertificateMonitoring.domains | toJson }}
    relabel_configs:
      - source_labels: [__address__]
        target_label: __param_target
      - source_labels: [__param_target]
        target_label: instance
      - source_labels: [__param_module]
        target_label: blackbox_probe_module
      - target_label: __address__
        replacement: prometheus-blackbox-exporter:9115
  {{- end }}

  {{- if and .Values.externalEndpointMonitoring.enabled .Values.externalEndpointMonitoring.domains }}
  blackbox-external-endpoint:
    metrics_path: /probe
    honor_timestamps: true
    scrape_interval: 15s
    scrape_timeout: 10s
    params:
    {{- if .Values.externalEndpointMonitoring.verifyCA }}
      module: [http_2xx_verify]
    {{- else }}
      module: [http_2xx]
    {{- end }}
    static_configs:
      - targets: {{ .Values.externalEndpointMonitoring.domains | toJson }}
    relabel_configs:
      - source_labels: [__address__]
        target_label: __param_target
      - source_labels: [__param_target]
        target_label: instance
      - source_labels: [__param_module]
        target_label: blackbox_probe_module
      - target_label: __address__
        replacement: prometheus-blackbox-exporter:9115
  {{- end }}

  {{- if .Values.calico.enabled }}
  calico:
    kubernetes_sd_configs:
    - role: pod
      namespaces:
        names:
        - kube-system
    relabel_configs:
      - source_labels: [__meta_kubernetes_pod_label_k8s_app]
        action: keep
        regex: calico-node
      - source_labels: [__address__]
        action: replace
        regex: ([^:]+)(?::\d+)?
        replacement: $1:9091
        target_label: __address__
      - source_labels: [__meta_kubernetes_namespace]
        target_label: namespace
      - source_labels: [__meta_kubernetes_pod_name]
        target_label: pod
      - source_labels: [__meta_kubernetes_pod_node_name]
        target_label: node
  {{- end }}

  {{- if .Values.nginxExporter.enabled }}
  prometheus-nginx-exporter:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_app]
      regex: prometheus-nginx-exporter
      action: keep
    - source_labels: [__meta_kubernetes_endpoint_port_name]
      regex: http-metrics
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
    - source_labels: [__meta_kubernetes_service_label_jobLabel]
      target_label: job
  {{- end }}

  {{- if .Values.logging.enabled }}
  prometheus-elasticsearch-exporter:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_app,__meta_kubernetes_endpoint_port_name]
      regex: elasticsearch-exporter;http-metrics
      action: keep
    - source_labels: [__meta_kubernetes_service_label_jobLabel]
      target_label: job

  fluentd:
    kubernetes_sd_configs:
      - role: pod
    relabel_configs:
      - source_labels: [__meta_kubernetes_pod_label_app_kubernetes_io_name]
        action: keep
        regex: fluentd-elasticsearch
      - source_labels: [__meta_kubernetes_pod_annotation_prometheus_io_path]
        action: replace
        target_label: __metrics_path__
        regex: (.+)
      - source_labels: [__address__, __meta_kubernetes_pod_annotation_prometheus_io_port]
        action: replace
        regex: ([^:]+)(?::\d+)?;(\d+)
        replacement: $1:$2
        target_label: __address__
      - source_labels: [__meta_kubernetes_namespace]
        target_label: namespace
      - source_labels: [__meta_kubernetes_pod_name]
        target_label: pod
      - source_labels: [__meta_kubernetes_pod_node_name]
        target_label: node

  prometheus-es-exporter:
    scrape_interval: '1m'
    scrape_timeout: '30s'
    honor_labels: true
    kubernetes_sd_configs:
      - role: service
    relabel_configs:
      - source_labels: [__meta_kubernetes_service_label_app]
        action: keep
        regex: prometheus-es-exporter
  {{- end }}

  {{- if .Values.alertmanagerSimpleConfig.msteams.enabled }}
  prometheus-msteams:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http

    kubernetes_sd_configs:
    - role: endpoints

    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_app]
      regex: prometheus-msteams
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
  {{- end }}

  prometheus-relay:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_component, __meta_kubernetes_service_name]
      regex: prometheus;relay;prometheus-relay
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - target_label: endpoint
      replacement: metrics

  {{- if .Values.alertmanagerSimpleConfig.salesForce.enabled }}
  sf-notifier:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
      - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_app]
      regex: sf-notifier
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_service_label_jobLabel]
      target_label: job
  {{- end }}

  {{- if .Values.alertmanagerSimpleConfig.serviceNow.enabled }}
  alertmanager-webhook-servicenow:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
      - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_app]
      regex: alertmanager-webhook-servicenow
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_service_label_jobLabel]
      target_label: job
  {{- end }}

  {{- $externalFQDNs := or (not (empty .Values.openstack.externalFQDN)) .Values.openstack.externalFQDNs.enabled }}
  {{- if .Values.openstack.enabled }}
    {{- if $externalFQDNs }}
  openstack-blackbox-ext:
    metrics_path: /probe
    kubernetes_sd_configs:
    - role: ingress
      namespaces:
        names:
        - openstack
    relabel_configs:
    - source_labels: [__meta_kubernetes_ingress_scheme, __meta_kubernetes_ingress_name, __address__]
      regex: 'https;[^;]+-namespace-fqdn;[^;]*\.[^;]*'
      action: keep
    - source_labels: [__meta_kubernetes_ingress_host]
      regex: '([^\.]+)(?:\..*|$)'
      replacement: '$1'
      target_label: service_name
    - source_labels: [__address__]
      target_label: instance
    - source_labels: [__meta_kubernetes_ingress_scheme, instance]
      regex: '([^;]+);([^;]+)'
      replacement: '$1://$2'
      target_label: __param_target
    - source_labels: [__meta_kubernetes_ingress_scheme, instance]
      regex: '([^;]+);(novncproxy.[^;]+)'
      replacement: '$1://$2/vnc_auto.html'
      target_label: __param_target
    - target_label: __param_module
    {{- if .Values.openstack.insecure.external }}
      replacement: http_openstack_insecure
    {{- else }}
      replacement: http_openstack
    {{- end }}
    - source_labels: [__param_module]
      target_label: blackbox_probe_module
    - target_label: __address__
      replacement: prometheus-blackbox-exporter:9115
    {{- end }}

  telegraf-openstack:
    scrape_interval: '{{ .Values.openstack.telegraf.interval }}'
    scrape_timeout: '30s'
    honor_labels: true
    kubernetes_sd_configs:
      - role: service
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name]
      regex: telegraf-openstack
      action: keep

  prometheus-libvirt-exporter:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 15s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name]
      regex: prometheus-libvirt-exporter
      action: keep
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: host

  prometheus-memcached-exporter:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
      namespaces:
        names:
        - openstack
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_application, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
      regex: prometheus_memcached_exporter;metrics;metrics
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: cluster
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod

  prometheus-mysql-exporter:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
      namespaces:
        names:
        - openstack
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_application, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
      regex: prometheus-mysql-exporter;metrics;metrics
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: cluster
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod

  openstack-ingress-controller:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
      namespaces:
        names:
        - openstack
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_application, __meta_kubernetes_endpoint_port_name]
      regex: ingress_exporter;metrics
      action: keep

    {{- if and (not .Values.tungstenFabricMonitoring.enabled) (.Values.openstack.arpingCheck.enabled) }}
  telegraf-ds-arping-check:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 15s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name]
      regex: telegraf-ds-arping-check
      action: keep
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
    {{- end }}
  {{- end }}

  {{- if or .Values.openstack.enabled .Values.tungstenFabricMonitoring.enabled }}
  prometheus-rabbitmq-exporter:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
      namespaces:
        names:
    {{- if .Values.openstack.enabled }}
        - openstack
    {{- end }}
    {{- if .Values.tungstenFabricMonitoring.enabled }}
        - tf
    {{- end }}
    metric_relabel_configs:
    - regex: 'self'
      action: labeldrop
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_application, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
      regex: prometheus_rabbitmq_exporter;metrics;metrics
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
  {{- end }}

  {{- if .Values.tungstenFabricMonitoring.enabled }}
  rabbitmq-operator-metrics:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
      namespaces:
        names:
        - tf
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_name, __meta_kubernetes_endpoint_port_name]
      regex: rabbitmq-operator;cr-metrics
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
  {{- end }}

  {{- if .Values.ceph.enabled }}
  prometheus-ceph:
    honor_timestamps: true
    honor_labels: false
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
      namespaces:
        names:
        - rook-ceph
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_endpoint_port_name]
      regex: rook-ceph-mgr;http-metrics
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_service_label_rook_cluster]
      target_label: rook_cluster
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
    - source_labels: [__meta_kubernetes_service_label_app]
      target_label: job
  {{- end }}

  {{- if .Values.ironic.enabled }}
  ironic:
    scrape_interval: '30s'
    scrape_timeout: '15s'
    honor_labels: true
    kubernetes_sd_configs:
    - role: service
      namespaces:
        names:
        - kaas
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name,__meta_kubernetes_service_port_name]
      regex: ironic-kaas-bm;ironic-telemetry
      action: keep
  {{- end }}

  {{- if eq .Values.provider "BareMetal" }}
  telegraf-ds-smart:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 15s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name]
      regex: telegraf-ds-smart
      action: keep
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
  {{- end }}

  {{- if .Values.telemetry.telemeterServer.enabled }}
  telemeter-federate:
    scrape_interval: '1m'
    scrape_timeout: '30s'
    honor_labels: true
    metrics_path: '/federate'
    params:
      'match[]':
        - '{__name__=~".+"}'
    kubernetes_sd_configs:
      - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name,__meta_kubernetes_endpoint_port_name]
      regex: telemeter-server;internal.*
      action: keep

  telemeter-server:
    scrape_interval: '30s'
    scrape_timeout: '15s'
    honor_labels: true
    kubernetes_sd_configs:
      - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name,__meta_kubernetes_endpoint_port_name]
      regex: telemeter-server;internal.*
      action: keep
  {{- end }}

  {{- if .Values.telemetry.telemeterClient.enabled }}
  telemeter-client:
    scrape_interval: '30s'
    scrape_timeout: '15s'
    honor_labels: true
    kubernetes_sd_configs:
      - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name]
      regex: telemeter-client
      action: keep
  {{- end }}

  kubernetes-master-api:
    metrics_path: /probe
    honor_timestamps: true
    scrape_interval: 15s
    scrape_timeout: 10s
    params:
      module: [http_2xx]
    kubernetes_sd_configs:
      - role: node
    relabel_configs:
      - source_labels: [__meta_kubernetes_node_labelpresent_node_role_kubernetes_io_master]
        action: keep
        regex: true
      - source_labels: [__meta_kubernetes_node_address_InternalIP]
        regex: (.+)
  {{- if .Values.mke.enabled }}
        replacement: 'https://${1}:{{ $MKEKubernetesAPIPort }}/healthz'
  {{- else if eq .Values.provider "BareMetal" }}
        replacement: 'https://${1}:6443/healthz'
  {{- else }}
        replacement: 'https://${1}:443/healthz'
  {{- end }}
        target_label: __param_target
      - source_labels: [__meta_kubernetes_node_name]
        target_label: node
      - source_labels: [__param_target]
        target_label: instance
      - source_labels: [__param_module]
        target_label: blackbox_probe_module
      - target_label: __address__
        replacement: prometheus-blackbox-exporter:9115

  prometheus-etcd:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    kubernetes_sd_configs:
  {{- if .Values.mke.enabled }}
    - role: node
  {{- else }}
    - role: endpoints
      namespaces:
        names:
        - kube-system
  {{- end }}
    scheme: https
    tls_config:
      ca_file: /tmp/mkecerts/ca.pem
      cert_file: /tmp/mkecerts/cert.pem
      insecure_skip_verify: true
      key_file: /tmp/mkecerts/key.pem
      server_name: ucp-controller.kube-system.svc.cluster.local
    relabel_configs:
  {{- if .Values.mke.enabled }}
    - source_labels: [__meta_kubernetes_node_labelpresent_node_role_kubernetes_io_master]
      regex: true
  {{- else }}
    - source_labels: [__meta_kubernetes_service_name]
      regex: ucp-controller
  {{- end }}
      action: keep
    - source_labels: [__address__]
      action: replace
      regex: ([^:]+)(?::\d+)?
      replacement: $1:12379
      target_label: __address__
  {{- if .Values.mke.enabled }}
    - source_labels: [__meta_kubernetes_node_name]
      target_label: node
  {{- else }}
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
  {{- end }}

  {{- if or .Values.mccTLSCertificateMonitoringEnabled .Values.kaasTLSCertificateMonitoringEnabled }}
  mcc-blackbox:
    metrics_path: /probe
    kubernetes_sd_configs:
    - role: service
      namespaces:
        names:
        - kaas
    - role: endpoints
      namespaces:
        names:
        - kaas
    relabel_configs:
    # "__meta_kubernetes_service_type" label introduced in Prom 2.17 would be useful here
    # <or filter>
    - source_labels: [__meta_kubernetes_service_port_name, __meta_kubernetes_service_cluster_ip]
      regex: '(?:web|https);\d+\.\d+\.\d+\.\d+'
      replacement: 'yes'
      target_label: scrape
    - source_labels: [__meta_kubernetes_endpoint_port_name, __meta_kubernetes_endpoint_ready]
      regex: '(?:web|https);true'
      replacement: 'yes'
      target_label: scrape
    - source_labels: [scrape]
      regex: 'yes'
      action: keep
    - action: labeldrop
      regex: 'scrape'
    # </or filter>
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service_name
    - source_labels: [__meta_kubernetes_endpoint_address_target_kind, __meta_kubernetes_endpoint_address_target_name]
      regex: 'Pod;([^;]+)'
      replacement: '$1'
      target_label: pod
    - source_labels: [__address__]
      target_label: instance
    - source_labels: [__meta_kubernetes_service_port_name, instance]
      regex: '(?:https|web);([^;]+)'
      replacement: '$1'
      target_label: __param_target
    - source_labels: [__meta_kubernetes_endpoint_port_name, instance]
      regex: '(?:https|web);([^;]+)'
      replacement: '$1'
      target_label: __param_target
    - target_label: __param_module
      replacement: tls
    - source_labels: [__param_module]
      target_label: blackbox_probe_module
    - target_label: __address__
      replacement: prometheus-blackbox-exporter:9115
  {{- end }}

  {{- if .Values.kaasExporterEnabled }}
  kaas-exporter:
    scrape_interval: '60s'
    scrape_timeout: '30s'
    honor_labels: true
    kubernetes_sd_configs:
      - role: service
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name]
      regex: kaas-exporter
      action: keep
    metric_relabel_configs:
    - source_labels: [__name__, cluster_id]
      regex: "kaas_machines_(ready|requested);(.+)"
      replacement: $2
      target_label: exported_cluster_id
  {{- end }}

  {{- if .Values.tungstenFabricMonitoring.enabled }}
  tf-cassandra-jmx-exporter:
    honor_timestamps: true
    scrape_interval: 30s
    scrape_timeout: 10s
    metrics_path: /metrics
    scheme: http
    kubernetes_sd_configs:
    - role: endpoints
      namespaces:
        names:
        - tf
    relabel_configs:
    - source_labels:
      - __meta_kubernetes_service_label_app
      - __meta_kubernetes_service_label_k8s_app
      - __meta_kubernetes_endpoint_port_name
      regex: cassandracluster;exporter-cassandra-jmx;promjmx
      action: keep
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_label_cassandracluster]
      target_label: cluster
    - source_labels: [__meta_kubernetes_pod_label_cassandraclusters_db_orange_com_dc]
      target_label: datacenter
    - source_labels: [__meta_kubernetes_pod_label_cassandraclusters_db_orange_com_rack]
      target_label: rack

  tf-redis:
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - action: keep
      source_labels: [__meta_kubernetes_service_label_name, __meta_kubernetes_service_label_redis, __meta_kubernetes_endpoint_port_name]
      regex: 'tf-redis;tf-redis;exporter'
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
    - source_labels: [__meta_kubernetes_pod_label_redis]
      target_label: cluster

  tf-zookeeper:
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - action: keep
      source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_headless, __meta_kubernetes_endpoint_port_name]
      regex: 'tf-zookeeper[^;]*;true;tcp-metrics'
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
    - source_labels: [__meta_kubernetes_pod_label_app]
      target_label: cluster

  tf-control:
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - action: keep
      source_labels: [__meta_kubernetes_service_name]
      regex: 'prometheus-tf-controller-exporter'
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node

  tf-kafka-jmx:
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - action: keep
      source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
      regex: 'tf-kafka;kafka-broker;http-metrics'
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
    - source_labels: [__meta_kubernetes_pod_label_app]
      target_label: cluster

  tf-vrouter:
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - action: keep
      source_labels: [__meta_kubernetes_service_name]
      regex: 'prometheus-tf-vrouter-exporter'
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
  {{- end }}

  postgresql:
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name]
      regex: patroni(?:-[0-9a-f]+)?-readonly
      action: keep
    - source_labels: [__address__]
      action: replace
      regex: ([^:]+)(?::\d+)?
      replacement: $1:9187
      target_label: __address__
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_label_release]
      target_label: cluster
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
    metric_relabel_configs:
    # `server` label is irrelevant when exporter is co-located in pod, due to reporting localhost
    - regex: server
      action: labeldrop

  patroni:
    kubernetes_sd_configs:
    - role: endpoints
    relabel_configs:
    - source_labels: [__meta_kubernetes_service_name]
      regex: patroni(?:-[0-9a-f]+)?-readonly
      action: keep
    - source_labels: [__address__]
      action: replace
      regex: ([^:]+)(?::\d+)?
      replacement: $1:9547
      target_label: __address__
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_label_release]
      target_label: cluster
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node

  stacklight-generic:
    metrics_path: /metrics
    kubernetes_sd_configs:
    - role: endpoints
    - role: service
    relabel_configs:
    # <or filter>
    # "generic.stacklight.mirantis.com/scrape-port": "8080"
    - source_labels: [__meta_kubernetes_service_annotationpresent_generic_stacklight_mirantis_com_scrape_port]
      regex: 'true'
      replacement: 'yes'
      target_label: scrape
    # "generic.stacklight.mirantis.com/scrape-path": "/custom_metrics"
    - source_labels: [__meta_kubernetes_service_annotationpresent_generic_stacklight_mirantis_com_scrape_path]
      regex: 'true'
      replacement: 'yes'
      target_label: scrape
    # "generic.stacklight.mirantis.com/scrape-scheme": "https"
    - source_labels: [__meta_kubernetes_service_annotationpresent_generic_stacklight_mirantis_com_scrape_scheme]
      regex: 'true'
      replacement: 'yes'
      target_label: scrape
    - source_labels: [scrape]
      regex: 'yes'
      action: keep
    - action: labeldrop
      regex: 'scrape'
    # </or filter>
    # <k8s resource names>
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service_name
    - source_labels: [__meta_kubernetes_endpoint_address_target_kind, __meta_kubernetes_endpoint_address_target_name]
      regex: 'Pod;([^;]+)'
      replacement: '$1'
      target_label: pod
    # </k8s resource names>
    # <scrape config through annotations>
    - source_labels: [__meta_kubernetes_service_annotation_generic_stacklight_mirantis_com_scrape_scheme]
      regex: '(.+)'
      target_label: __scheme__
    - source_labels: [__address__, __meta_kubernetes_service_annotation_generic_stacklight_mirantis_com_scrape_port]
      regex: '([^:]+)(?::\d+)?;(\d+)'
      replacement: $1:$2
      target_label: __address__
    - source_labels: [__meta_kubernetes_service_annotation_generic_stacklight_mirantis_com_scrape_path]
      regex: '(.+)'
      replacement: '$1'
      target_label: __metrics_path__
    # </scrape config through annotations>
{{- end }}

{{- define "prometheus.server" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "crit" "error") "component" "prometheusServer" | include "stacklight.logLevel" -}}
server:
  global:
    scrape_interval: 15s
    scrape_timeout: 10s
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "prometheus") | nindent 4 }}
  affinity:
    podAntiAffinity:
      preferredDuringSchedulingIgnoredDuringExecution:
      - weight: 1
        podAffinityTerm:
          topologyKey: "kubernetes.io/hostname"
          labelSelector:
            matchExpressions:
            - key: app
              operator: In
              values:
              - "elasticsearch-master"
            - key: component
              operator: In
              values:
              - "master"
  {{- if .Values.openstack.enabled }}
      - weight: 1
        podAffinityTerm:
          topologyKey: "kubernetes.io/hostname"
          namespaces: ["{{ .Values.openstack.namespace }}"]
          labelSelector:
            matchExpressions:
            - key: application
              operator: In
              values:
              - "mariadb"
            - key: component
              operator: In
              values:
              - "server"
  {{- end }}
  {{- if .Values.highAvailabilityEnabled }}
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app
            operator: In
            values:
            - "prometheus"
          - key: component
            operator: In
            values:
            - "server"
        topologyKey: "kubernetes.io/hostname"
  replicaCount: 2
  {{- else }}
  strategy:
    type: RollingUpdate
    rollingUpdate:
      maxUnavailable: 1
      maxSurge: 0
  {{- end }}
  {{- $prometheusRetentionTime := .Values.prometheusServer.retentionTime }}
  {{- if .Values.cortexDev.enabled }}
    {{- $prometheusRetentionTime = "2d" }}
  {{- end }}
  retention: {{ $prometheusRetentionTime }}
  extraArgs:
    storage.tsdb.retention.size: {{ .Values.prometheusServer.retentionSize }}
    rules.alert.resend-delay: {{ .Values.prometheusServer.alertResendDelay }}
  {{- if $logLevel }}
    "log.level": {{ $logLevel | quote }}
  {{- end }}
  persistentVolume:
    size: {{ .Values.prometheusServer.persistentVolumeClaimSize }}
  {{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.prometheusServer }}
    {{- $storageClass := .Values.storage.defaultStorageClass }}
    {{- if .Values.storage.componentStorageClasses.prometheusServer }}
      {{- $storageClass = .Values.storage.componentStorageClasses.prometheusServer }}
    {{- end }}
    storageClass: "{{ $storageClass }}"
  {{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "prometheusServer") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "prometheusServer") | nindent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "prometheusServer") | nindent 2 }}
  {{- if .Values.mke.enabled }}
  extraHostPathMounts:
  - name: mkecerts
    hostPath: "{{ .Values.mke.dockerdDataRoot }}/volumes/ucp-node-certs/_data"
    mountPath: /tmp/mkecerts
    subPath: ""
    readOnly: true
  {{- end }}
  {{- if .Values.exposeLoadBalancers }}
  service:
    type: LoadBalancer
  {{- end }}
{{- if .Values.cortexDev.enabled }}
serverFiles:
  prometheus.yml:
    remote_write:
    - url: "http://cortex-distributor:8080/api/v1/push"
{{- end }}
{{- end }}

{{- define "prometheus.metricFilter" -}}
{{- if index .Values.metricFilter "enabled" }}
{{- $metricFilterNamespaces := list "kaas" "kube-system" "stacklight" }}
{{- if kindIs "map" .Values.metricFilter.namespaces }}
  {{- $metricFilterNamespaces = keys .Values.metricFilter.namespaces }}
{{- else if kindIs "slice" .Values.metricFilter.namespaces }}
  {{- $metricFilterNamespaces = .Values.metricFilter.namespaces }}
{{- end }}
metricFilter:
  cAdvisor:
  - action: {{ .Values.metricFilter.action }}
    labelRegexes:
      namespace: {{ $metricFilterNamespaces | sortAlpha | uniq | join "|" | quote }}
  kubeStateMetrics:
  - action: {{ .Values.metricFilter.action }}
    labelRegexes:
      namespace: {{ $metricFilterNamespaces | sortAlpha | uniq | join "|" | quote }}
{{- end -}}
{{- end -}}

{{- define "prometheus.relay" -}}
relay:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "prometheusRelay") | nindent 4 }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "prometheusRelay" ) | nindent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "prometheusRelay") | nindent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "prometheusRelay") | nindent 2 }}
{{- end -}}

{{- define "prometheus.alertsOverride" -}}
{{- $clusterId := include "stacklight.clusterId" . }}
{{- if not (empty $clusterId) }}
alertsCommonLabels:
  cluster_id: {{ $clusterId }}
{{- end }}

{{- if not .Values.cortexDev.enabled }}
alerts:
  {{- range $alertName, $alertValues := include "stacklight.getEnabledAlerts" . | fromYaml }}
  {{- $alertName | nindent 2 }}:
    {{- $alertValues | toYaml | nindent 4 }}
  {{- end }}
{{- end }}
{{- end -}}

{{- define "prometheus.extraRecordingRules" -}}
extraRecordingRules:
  extra-rules:
    groups:
    - name: api_availability.rules
      rules:
      - expr: |
          avg(probe_success{job=~".*-api$"}) by (job)
        record: api:probe_sucess
      - expr: |
          ceil(avg_over_time(api:probe_sucess[5m])) and api:probe_sucess and api:probe_sucess offset 5m
        record: api:probe_sucess:avg5m:for5m:ceil
      - expr: |
          floor(avg_over_time(api:probe_sucess:avg5m:for5m:ceil[5m]))
        record: api:probe_sucess:avg5m:for5m:ceil:avg5m:floor
  {{- if .Values.ceph.enabled }}
    - name: ceph.rules
      rules:
      - expr: |
          kube_node_status_condition{condition="Ready",job="kube-state-metrics",status="true"}
          *
          on (node) group_right()
            max(label_replace(ceph_disk_occupation{job="rook-ceph-mgr"},"node","$1","exported_instance","(.*)")) by (node, rook_cluster)
        record: cluster:ceph_node_down:join_kube
      - expr: |
          avg(
            max by(node) (
              label_replace(label_replace(ceph_disk_occupation{job="rook-ceph-mgr"}, "device", "$1", "device", "/dev/(.*)"), "node", "$1", "exported_instance", "(.*)")
              * on(node, device) group_right() (
                irate(node_disk_read_time_seconds_total[1m]) + irate(node_disk_write_time_seconds_total[1m])
                /
                (clamp_min(irate(node_disk_reads_completed_total[1m]), 1) + irate(node_disk_writes_completed_total[1m])))))
        record: cluster:ceph_disk_latency:join_ceph_node_disk_irate1m
    - name: telemeter.rules
      rules:
      - expr: |
          count(ceph_osd_metadata{job="rook-ceph-mgr"})
        record: job:ceph_osd_metadata:count
      - expr: |
          count(kube_persistentvolume_info)
        record: job:kube_pv:count
      - expr: |
          sum(ceph_pool_rd{job="rook-ceph-mgr"}+ ceph_pool_wr{job="rook-ceph-mgr"})
        record: job:ceph_pools_iops:total
      - expr: |
          sum(ceph_pool_rd_bytes{job="rook-ceph-mgr"}+ ceph_pool_wr_bytes{job="rook-ceph-mgr"})
        record: job:ceph_pools_iops_bytes:total
      - expr: |
          count(count(ceph_mon_metadata{job="rook-ceph-mgr"} or ceph_osd_metadata{job="rook-ceph-mgr"} or ceph_rgw_metadata{job="rook-ceph-mgr"} or ceph_mds_metadata{job="rook-ceph-mgr"} or ceph_mgr_metadata{job="rook-ceph-mgr"}) by(ceph_version))
        record: job:ceph_versions_running:count
  {{- end }}
  {{- if .Values.openstack.enabled }}
    - name: mysql.rules
      rules:
      - expr: mysql_slave_status_seconds_behind_master - mysql_slave_status_sql_delay
        record: mysql_slave_lag_seconds
      - expr: mysql_heartbeat_now_timestamp_seconds - mysql_heartbeat_stored_timestamp_seconds
        record: mysql_heartbeat_lag_seconds
      - expr: sum(rate(mysql_global_status_commands_total{command=~"(commit|rollback)"}[5m])) without (command)
        record: job:mysql_transactions:rate5m
    - name: nova-instance.rules
      rules:
      {{- if and (not .Values.tungstenFabricMonitoring.enabled) (.Values.openstack.arpingCheck.enabled) }}
      - expr: count(instance_id:instance_arping_success:avg10m:for10m or on(id) openstack_nova_instance_status) or vector(0)
        record: total:openstack_nova_instance_all
      - expr: count(instance_id:instance_arping_success:avg10m:for10m == 0 or on(id) openstack_nova_instance_status == 2) or vector(0)
        record: total:openstack_nova_instance_failed
      - expr: avg(instance_arping_success) by (id)
        record: instance_id:instance_arping_success
      - expr: avg_over_time(instance_id:instance_arping_success[10m]) and instance_id:instance_arping_success and instance_id:instance_arping_success offset 10m
        record: instance_id:instance_arping_success:avg10m:for10m
      {{- end }}
      - expr: count(openstack_nova_instance_status) without (id,name)
        record: total:openstack_nova_instance_status
      - expr: count(openstack_nova_instance_status == 2) without (id,name)
        record: total:openstack_nova_instance_status:error
      - expr: label_replace(count(label_replace(openstack_nova_running_instances,"host","$1","hostname","(.*)") unless on(host) openstack_nova_aggregate_metadata) without(hostname),"name","_no_host_aggregate","",".*")
        record: no_aggregate:openstack_nova_aggregate_metadata
    - name: linvirt-exporter.rules
      rules:
      - expr: sum(libvirt_domain_info_virtual_cpus) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_info_virtual_cpus
      - expr: sum(libvirt_domain_info_virtual_cpus) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_info_virtual_cpus
      - expr: rate(libvirt_domain_info_cpu_time_seconds_total[5m])
        record: libvirt_domain_info_cpu_time_seconds:rate5m
      - expr: sum(libvirt_domain_info_cpu_time_seconds:rate5m) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_info_cpu_time_seconds:rate5m
      - expr: sum(libvirt_domain_info_cpu_time_seconds:rate5m) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_info_cpu_time_seconds:rate5m
      - expr: sum(libvirt_domain_info_maximum_memory_bytes) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_info_maximum_memory_bytes
      - expr: sum(libvirt_domain_info_maximum_memory_bytes) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_info_maximum_memory_bytes
      - expr: sum(libvirt_domain_info_memory_usage_bytes) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_info_memory_usage_bytes
      - expr: sum(libvirt_domain_info_memory_usage_bytes) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_info_memory_usage_bytes
      - expr: sum(libvirt_domain_memory_unused_bytes) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_memory_unused_bytes
      - expr: sum(libvirt_domain_memory_unused_bytes) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_memory_unused_bytes
      - expr: sum(libvirt_domain_memory_available_bytes) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_memory_available_bytes
      - expr: sum(libvirt_domain_memory_available_bytes) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_memory_available_bytes
      - expr: sum(libvirt_domain_memory_actual_balloon_bytes) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_memory_actual_balloon_bytes
      - expr: sum(libvirt_domain_memory_actual_balloon_bytes) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_memory_actual_balloon_bytes
      - expr: sum(libvirt_domain_memory_rss_bytes) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_memory_rss_bytes
      - expr: sum(libvirt_domain_memory_rss_bytes) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_memory_rss_bytes
      - expr: sum(libvirt_domain_memory_usable_bytes) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_memory_usable_bytes
      - expr: sum(libvirt_domain_memory_usable_bytes) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_memory_usable_bytes
      - expr: rate(libvirt_domain_block_stats_read_bytes_total[5m])
        record: libvirt_domain_block_stats_read_bytes:rate5m
      - expr: sum(libvirt_domain_block_stats_read_bytes:rate5m) without (source_file,target_device)
        record: instance:libvirt_domain_block_stats_read_bytes:rate5m
      - expr: sum(libvirt_domain_block_stats_read_bytes:rate5m) by (host,project_name,project_uuid,type,user_name,user_uuid)
        record: host_user:libvirt_domain_block_stats_read_bytes:rate5m
      - expr: sum(libvirt_domain_block_stats_read_bytes:rate5m) by (host,project_name,project_uuid,type)
        record: host_project:libvirt_domain_block_stats_read_bytes:rate5m
      - expr: rate(libvirt_domain_block_stats_read_requests_total[5m])
        record: libvirt_domain_block_stats_read_requests:rate5m
      - expr: sum(libvirt_domain_block_stats_read_requests:rate5m) without (source_file,target_device)
        record: instance:libvirt_domain_block_stats_read_requests:rate5m
      - expr: sum(libvirt_domain_block_stats_read_requests:rate5m) by (host,project_name,project_uuid,type,user_name,user_uuid)
        record: host_user:libvirt_domain_block_stats_read_requests:rate5m
      - expr: sum(libvirt_domain_block_stats_read_requests:rate5m) by (host,project_name,project_uuid,type)
        record: host_project:libvirt_domain_block_stats_read_requests:rate5m
      - expr: rate(libvirt_domain_block_stats_write_bytes_total[5m])
        record: libvirt_domain_block_stats_write_bytes:rate5m
      - expr: sum(libvirt_domain_block_stats_write_bytes:rate5m) without (source_file,target_device)
        record: instance:libvirt_domain_block_stats_write_bytes:rate5m
      - expr: sum(libvirt_domain_block_stats_write_bytes:rate5m) by (host,project_name,project_uuid,type,user_name,user_uuid)
        record: host_user:libvirt_domain_block_stats_write_bytes:rate5m
      - expr: sum(libvirt_domain_block_stats_write_bytes:rate5m) by (host,project_name,project_uuid,type)
        record: host_project:libvirt_domain_block_stats_write_bytes:rate5m
      - expr: rate(libvirt_domain_block_stats_write_requests_total[5m])
        record: libvirt_domain_block_stats_write_requests:rate5m
      - expr: sum(libvirt_domain_block_stats_write_requests:rate5m) without (source_file,target_device)
        record: instance:libvirt_domain_block_stats_write_requests:rate5m
      - expr: sum(libvirt_domain_block_stats_write_requests:rate5m) by (host,project_name,project_uuid,type,user_name,user_uuid)
        record: host_user:libvirt_domain_block_stats_write_requests:rate5m
      - expr: sum(libvirt_domain_block_stats_write_requests:rate5m) by (host,project_name,project_uuid,type)
        record: host_project:libvirt_domain_block_stats_write_requests:rate5m
      - expr: sum(libvirt_domain_block_stats_allocation) without (source_file,target_device)
        record: instance:libvirt_domain_block_stats_allocation
      - expr: sum(libvirt_domain_block_stats_allocation) by (host,project_name,project_uuid,type,user_name,user_uuid)
        record: host_user:libvirt_domain_block_stats_allocation
      - expr: sum(libvirt_domain_block_stats_allocation) by (host,project_name,project_uuid,type)
        record: host_project:libvirt_domain_block_stats_allocation
      - expr: sum(libvirt_domain_block_stats_capacity) without (source_file,target_device)
        record: instance:libvirt_domain_block_stats_capacity
      - expr: sum(libvirt_domain_block_stats_capacity) by (host,project_name,project_uuid,type,user_name,user_uuid)
        record: host_user:libvirt_domain_block_stats_capacity
      - expr: sum(libvirt_domain_block_stats_capacity) by (host,project_name,project_uuid,type)
        record: host_project:libvirt_domain_block_stats_capacity
      - expr: sum(libvirt_domain_block_stats_physical) without (source_file,target_device)
        record: instance:libvirt_domain_block_stats_physical
      - expr: sum(libvirt_domain_block_stats_physical) by (host,project_name,project_uuid,type,user_name,user_uuid)
        record: host_user:libvirt_domain_block_stats_physical
      - expr: sum(libvirt_domain_block_stats_physical) by (host,project_name,project_uuid,type)
        record: host_project:libvirt_domain_block_stats_physical
      - expr: rate(libvirt_domain_interface_stats_receive_drops_total[5m])
        record: libvirt_domain_interface_stats_receive_drops:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_drops:rate5m) without (source_bridge,target_device)
        record: instance:libvirt_domain_interface_stats_receive_drops:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_drops:rate5m) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_interface_stats_receive_drops:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_drops:rate5m) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_interface_stats_receive_drops:rate5m
      - expr: rate(libvirt_domain_interface_stats_receive_errors_total[5m])
        record: libvirt_domain_interface_stats_receive_errors:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_errors:rate5m) without (source_bridge,target_device)
        record: instance:libvirt_domain_interface_stats_receive_errors:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_errors:rate5m) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_interface_stats_receive_errors:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_errors:rate5m) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_interface_stats_receive_errors:rate5m
      - expr: rate(libvirt_domain_interface_stats_receive_packets_total[5m])
        record: libvirt_domain_interface_stats_receive_packets:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_packets:rate5m) without (source_bridge,target_device)
        record: instance:libvirt_domain_interface_stats_receive_packets:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_packets:rate5m) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_interface_stats_receive_packets:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_packets:rate5m) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_interface_stats_receive_packets:rate5m
      - expr: rate(libvirt_domain_interface_stats_transmit_bytes_total[5m])
        record: libvirt_domain_interface_stats_transmit_bytes:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_bytes:rate5m) without (source_bridge,target_device)
        record: instance:libvirt_domain_interface_stats_transmit_bytes:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_bytes:rate5m) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_interface_stats_transmit_bytes:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_bytes:rate5m) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_interface_stats_transmit_bytes:rate5m
      - expr: rate(libvirt_domain_interface_stats_transmit_drops_total[5m])
        record: libvirt_domain_interface_stats_transmit_drops:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_drops:rate5m) without (source_bridge,target_device)
        record: instance:libvirt_domain_interface_stats_transmit_drops:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_drops:rate5m) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_interface_stats_transmit_drops:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_drops:rate5m) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_interface_stats_transmit_drops:rate5m
      - expr: rate(libvirt_domain_interface_stats_transmit_errors_total[5m])
        record: libvirt_domain_interface_stats_transmit_errors:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_errors:rate5m) without (source_bridge,target_device)
        record: instance:libvirt_domain_interface_stats_transmit_errors:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_errors:rate5m) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_interface_stats_transmit_errors:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_errors:rate5m) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_interface_stats_transmit_errors:rate5m
      - expr: rate(libvirt_domain_interface_stats_transmit_packets_total[5m])
        record: libvirt_domain_interface_stats_transmit_packets:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_packets:rate5m) without (source_bridge,target_device)
        record: instance:libvirt_domain_interface_stats_transmit_packets:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_packets:rate5m) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_interface_stats_transmit_packets:rate5m
      - expr: sum(libvirt_domain_interface_stats_transmit_packets:rate5m) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_interface_stats_transmit_packets:rate5m
      - expr: rate(libvirt_domain_interface_stats_receive_bytes_total[5m])
        record: libvirt_domain_interface_stats_receive_bytes:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_bytes:rate5m) without (source_bridge,target_device)
        record: instance:libvirt_domain_interface_stats_receive_bytes:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_bytes:rate5m) by (host,project_name,project_uuid,user_name,user_uuid)
        record: host_user:libvirt_domain_interface_stats_receive_bytes:rate5m
      - expr: sum(libvirt_domain_interface_stats_receive_bytes:rate5m) by (host,project_name,project_uuid)
        record: host_project:libvirt_domain_interface_stats_receive_bytes:rate5m
  {{- end }}

  {{- if or .Values.telemetry.telemeterClient.enabled .Values.telemetry.telemeterServer.enabled }}
    {{- $mcncMetrics := dict }}
    {{- $telemeterRecordingRules := dict }}
    {{- range $record, $rule := .Files.Get "files/telemeter-recording-rules.yaml" | fromYaml }}
      {{- $_ := set $telemeterRecordingRules $record $rule.expr }}
      {{- if index $rule "mcnc" }}
        {{- $_ := set $mcncMetrics $record $rule.expr }}
      {{- end }}
    {{- end }}
    {{- $id := .Values.telemetry.telemeterServer.id }}
    {{- if .Values.telemetry.telemeterClient.enabled }}
      {{- $id = .Values.telemetry.telemeterClient.id }}
    {{- end }}

    - name: telemetry.rules
      rules:

    {{- /* a bunch of rules for adding the cluster_id label to the metrics */}}
    {{- range $record, $expr := $telemeterRecordingRules }}
      - expr: |
          label_replace({{ $expr }}, "cluster_id", "{{ $id }}", "", "")
        record: telemetry:{{ $record }}
    {{- end }}

    {{- $idKey := "cluster_id" }}
    {{- if .Values.telemetry.clusterIdLabelInjection.enabled }}
      {{- $idKey = .Values.telemetry.clusterIdLabelInjection.key }}

      {{- /* a bunch of rules for adding the region_id/management_id label to the metrics */}}
      {{- range $record, $expr := $telemeterRecordingRules }}
      - expr: |
        {{- if eq $idKey "management_id" }}
          label_replace(avg(label_replace(telemetry:{{ $record }}{ {{ $idKey }} ="", cluster_id!=""}, "{{ $idKey }}", "{{ $id }}", "", "")) without(_id), "region_id", "{{ $id }}", "region_id", "")
        {{- else }}
          avg(label_replace(telemetry:{{ $record }}{ {{ $idKey }} ="", cluster_id!=""}, "{{ $idKey }}", "{{ $id }}", "", "")) without(_id)
        {{- end }}
        record: telemetry:{{ $record }}
      {{- end }}

    {{- end }}

    {{- if .Values.telemetry.metricCollector.enabled }}

      {{- /* a bunch of rules for preparing the mcnc metrics (in general it is a subset of telemetry metrics) */}}
      {{- range $record, $_ := $mcncMetrics }}
      - expr: |
          avg(telemetry:{{ $record }}{ {{ $idKey }} !="", cluster_id!=""}) without(_id)
        record: mcnc:{{ $record }}
      {{- end }}

    {{- end }}
  {{- end }}
{{- end -}}

{{- define "prometheus.initChownData" -}}
initChownData:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "busybox") | nindent 4 }}
{{- end }}

{{- define "prometheus.configmapReload" -}}
configmapReload:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "configmapReload") | nindent 4 }}
{{- end }}

{{- define "prometheus.kubeStateMetrics" -}}
{{/* https://github.com/kubernetes/community/blob/master/contributors/devel/sig-instrumentation/logging.md */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "5" "debug" "4" "info" "3" "warn" "1" "error" "0" "crit" "0") "component" "kubeStateMetrics" | include "stacklight.logLevel" -}}
kubeStateMetrics:
  {{- if $logLevel }}
  args:
    "v": {{ $logLevel | quote }}
  {{- end }}
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "kubeStateMetrics") | nindent 4 }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "kubeStateMetrics") | nindent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "kubeStateMetrics") | nindent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "kubeStateMetrics") | nindent 2 }}
{{- end }}

{{- define "prometheus.iam" -}}
  {{- if .Values.iam.enabled }}
iam:
  enabled: true
  {{- end }}
{{- end }}

{{- define "prometheus.init" -}}
initExternalIP:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "curlJq") | nindent 4 }}
initYamlMerge:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "yq") | nindent 4 }}
{{- end }}
